---
title: pymdownx.progressbar
---


[Reference](https://facelessuser.github.io/pymdown-extensions/extensions/progressbar/){: class="reference" }

You can leverage `attr_list` to colorize the progress bar.

```md
[=50% ""]
[=75% "75%"]
[=95% "Awesome"]{: .success}
[=25% "25%"]{: .warning}
[=5% "5%"]{: .danger}
```

[=50% ""]
[=75% "75%"]
[=95% "Awesome"]{: .success}
[=25% "25%"]{: .warning}
[=5% "5%"]{: .danger}
